Trait FloatingTabRippleExt
pub trait FloatingTabRippleExt {
// Required method
fn ripple(self) -> RippleFloatingTab;
}Available on crate feature
material-design only.Expand description
Extension trait that adds ripple effect support to FloatingTab.
This trait provides the FloatingTabRippleExt::ripple method that wraps the tab’s children in a Ripple component, creating a Material Design-style ripple effect on click.
Example
fn app() -> impl IntoElement {
FloatingTab::new().ripple().child("Home")
}Required Methods
fn ripple(self) -> RippleFloatingTab
fn ripple(self) -> RippleFloatingTab
Enable ripple effect on this floating tab. Returns a RippleFloatingTab that allows adding children and configuring the ripple.