Trait TileRippleExt
pub trait TileRippleExt {
// Required method
fn ripple(self) -> RippleTile;
}Available on crate feature
material-design only.Expand description
Extension trait that adds ripple effect support to Tile.
This trait provides the TileRippleExt::ripple method that wraps the tile’s children in a Ripple component, creating a Material Design-style ripple effect on click.
Example
fn app() -> impl IntoElement {
let mut checked = use_state(|| false);
Tile::new()
.on_select(move |_| checked.toggle())
.ripple()
.leading(Checkbox::new().selected(checked()))
.child("Enable notifications")
}Required Methods
fn ripple(self) -> RippleTile
fn ripple(self) -> RippleTile
Enable ripple effect on this tile. Returns a RippleTile that allows adding children and configuring the ripple.